==> api-platform-doc-parsing-check-0.1.2.tgz: package/lib/index.js <==
#!/usr/bin/env node
'use strict';

var _getIterator2 = require('babel-runtime/core-js/get-iterator');

var _getIterator3 = _interopRequireDefault(_getIterator2);

require('isomorphic-fetch');

var _commander = require('commander');

var _commander2 = _interopRequireDefault(_commander);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _parseHydraDocumentation = require('api-doc-parser/lib/hydra/parseHydraDocumentation');

var _parseHydraDocumentation2 = _interopRequireDefault(_parseHydraDocumentation);

var _package = require('../package.json');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_commander2.default.version(_package.version).description('Check API Hydra documentation parsing').usage('entrypoint').parse(process.argv);

if (1 !== _commander2.default.args.length) {
  _commander2.default.help();
}

var entrypoint = _commander2.default.args[0];

(0, _parseHydraDocumentation2.default)(entrypoint).then(function (api) {
  var count = 0;
  var endpoints = [];
  console.log();
  console.log(_chalk2.default.green('Checking documentation parsing for API @ ') + entrypoint);
  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _iterator = (0, _getIterator3.default)(api.api.resources), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      var resource = _step.value;

      count++;
      var nameLc = resource.name.toLowerCase();
      endpoints.push(nameLc);
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }

  console.log(endpoints.sort());
  console.log(_chalk2.default.green('Number of endpoints parsed : ') + count);
}).catch(function (e) {
  console.log(e);
});

==> api-platform-doc-parsing-check-0.1.4.tgz: package/lib/index.js <==
#!/usr/bin/env node
'use strict';

var _getIterator2 = require('babel-runtime/core-js/get-iterator');

var _getIterator3 = _interopRequireDefault(_getIterator2);

require('isomorphic-fetch');

var _commander = require('commander');

var _commander2 = _interopRequireDefault(_commander);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _parseHydraDocumentation = require('@api-platform/api-doc-parser/lib/hydra/parseHydraDocumentation');

var _parseHydraDocumentation2 = _interopRequireDefault(_parseHydraDocumentation);

var _package = require('../package.json');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_commander2.default.version(_package.version).description('Check API Hydra documentation parsing').usage('entrypoint').parse(process.argv);

if (1 !== _commander2.default.args.length) {
  _commander2.default.help();
}

var entrypoint = _commander2.default.args[0];

(0, _parseHydraDocumentation2.default)(entrypoint).then(function (api) {
  var count = 0;
  var endpoints = [];
  console.log();
  console.log(_chalk2.default.green('Checking documentation parsing for API @ ') + entrypoint);
  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _iterator = (0, _getIterator3.default)(api.api.resources), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      var resource = _step.value;

      count++;
      var nameLc = resource.name.toLowerCase();
      endpoints.push(nameLc);
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }

  console.log(endpoints.sort());
  console.log(_chalk2.default.green('Number of endpoints parsed : ') + count);
}).catch(function (e) {
  console.log(e);
});
